Documentation
¶
Index ¶
- func NewClusterResourceBindingInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterResourceBindingInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredResourceBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredWorkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewResourceBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewWorkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ClusterResourceBindingInformer
- type Interface
- type ResourceBindingInformer
- type WorkInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterResourceBindingInformer ¶
func NewClusterResourceBindingInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterResourceBindingInformer constructs a new informer for ClusterResourceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterResourceBindingInformer ¶
func NewFilteredClusterResourceBindingInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterResourceBindingInformer constructs a new informer for ClusterResourceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredResourceBindingInformer ¶
func NewFilteredResourceBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredResourceBindingInformer constructs a new informer for ResourceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredWorkInformer ¶
func NewFilteredWorkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredWorkInformer constructs a new informer for Work type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewResourceBindingInformer ¶
func NewResourceBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewResourceBindingInformer constructs a new informer for ResourceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewWorkInformer ¶
func NewWorkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewWorkInformer constructs a new informer for Work type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ClusterResourceBindingInformer ¶
type ClusterResourceBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterResourceBindingLister
}
ClusterResourceBindingInformer provides access to a shared informer and lister for ClusterResourceBindings.
type Interface ¶
type Interface interface {
// ClusterResourceBindings returns a ClusterResourceBindingInformer.
ClusterResourceBindings() ClusterResourceBindingInformer
// ResourceBindings returns a ResourceBindingInformer.
ResourceBindings() ResourceBindingInformer
// Works returns a WorkInformer.
Works() WorkInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type ResourceBindingInformer ¶
type ResourceBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ResourceBindingLister
}
ResourceBindingInformer provides access to a shared informer and lister for ResourceBindings.
type WorkInformer ¶
type WorkInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.WorkLister
}
WorkInformer provides access to a shared informer and lister for Works.